from IutyLib.database.mysql import MySql
from IutyLib.database.dbbase import *
from flask import session,request,send_from_directory
from flask_restful import Resource
import datetime,os


dbg = os.path.exists("./debug")
if dbg:
    mysql = MySql('139.9.137.187','root','fastcorp','dev',8510)
else:
    mysql = MySql('localhost','root','fastcorp','license')

class mac_info(mysql.Model):
    
    
    def queryByInfo(self,appname,projectname):
        data = self.query(where=r"appname = '{}' and projectname = '{}'".format(appname,projectname))
        return data
    
    def updateInfo(self,id,cpuid,boardid,pcname):
        self.update(value=[{"cpuid":cpuid,"boardid":boardid,"pcname":pcname}],where=r"id='{}'".format(id))
        pass
    
    def deleteInfo(self,id);
        self.update(value=[{"cpuid":null,"boardid":null,"pcname":null}],where=r"id='{}'".format(id))
        pass
    
    pass

class proj_info(mysql.Model):
    
    
    def queryByInfo(self,appname,projectname):
        data = self.query(where=r"appname = '{}' and projectname = '{}'".format(appname,projectname))
        return data
    
    
    pass

    
class LicenseApi(Resource):
    def addLicense():
        rtn = {"success":False}
        
        appname = request.form.get('appname')
        if not appname:
            rtn["error"] = "appname is nesserary"
            return rtn
        
        projectname = request.form.get('projectname')
        if not projectname:
            rtn["error"] = "projectname is nesserary"
            return rtn
        
        cpuid = request.form.get('cpuid')
        if not cpuid:
            rtn["error"] = "cpuid is nesserary"
            return rtn
        
        boardid = request.form.get('boardid')
        if not boardid:
            rtn["error"] = "boardid is nesserary"
            return rtn
        
        pcname = request.form.get('pcname')
        if not pcname:
            rtn["error"] = "pcname is nesserary"
            return rtn
        db = mac_info()
        data = db.queryByInfo(appname,projectname)
        
        
        
        for d in data:
            if d["pcname"] == null:
                db.updateInfo(d["id"],cpuid,boardid,pcname)
                
                db1 = proj_info()
                rdata = db1.queryByInfo(appname,projectname)
                rtn["success"] = True
                rtn["data"] = datetime.datetime.strftime(rdata[0]["date"],'%Y-%m-%d')
                return rtn
        
        rtn["error"] = "no null data exists in license"
        return rtn
    
    def updateLicense():
        rtn = {"success":False}
        
        appname = request.form.get('appname')
        if not appname:
            rtn["error"] = "appname is nesserary"
            return rtn
        
        projectname = request.form.get('projectname')
        if not projectname:
            rtn["error"] = "projectname is nesserary"
            return rtn
        
        cpuid = request.form.get('cpuid')
        if not cpuid:
            rtn["error"] = "cpuid is nesserary"
            return rtn
        
        boardid = request.form.get('boardid')
        if not boardid:
            rtn["error"] = "boardid is nesserary"
            return rtn
        
        pcname = request.form.get('pcname')
        if not pcname:
            rtn["error"] = "pcname is nesserary"
            return rtn
        db = mac_info()
        data = db.queryByInfo(appname,projectname)
        
        
        
        for d in data:
            if (d["cpuid"] == cpuid) & (d['boardid'] == boardid):
                db.updateInfo(d["id"],cpuid,boardid,pcname)
                
                db1 = proj_info()
                rdata = db1.queryByInfo(appname,projectname)
                rtn["success"] = True
                rtn["data"] = datetime.datetime.strftime(rdata[0]["date"],'%Y-%m-%d')
                return rtn
        
        rtn["error"] = "no exists data exists in license"
        return rtn
    
    def removeLicense():
        rtn = {"success":False}
        
        appname = request.form.get('appname')
        if not appname:
            rtn["error"] = "appname is nesserary"
            return rtn
        
        projectname = request.form.get('projectname')
        if not projectname:
            rtn["error"] = "projectname is nesserary"
            return rtn
        
        cpuid = request.form.get('cpuid')
        if not cpuid:
            rtn["error"] = "cpuid is nesserary"
            return rtn
        
        boardid = request.form.get('boardid')
        if not boardid:
            rtn["error"] = "boardid is nesserary"
            return rtn
        
        
        db = mac_info()
        data = db.queryByInfo(appname,projectname)

        
        for d in data:
            if (d["cpuid"] == cpuid) & (d['boardid'] == boardid):
                db.deleteInfo(d["id"])
                
                
                rtn["success"] = True
                return rtn
        
        rtn["error"] = "no exists data exists in license"
        return rtn

    
    def post(self):
        _cmd = request.form.get('cmd')
        if _cmd == 'getApis':
            return ApiApi.getApis()
        
        if _cmd == 'getApiInfo':
            return ApiApi.getApiInfo()
        
        if _cmd == 'getNamespaces':
            return ApiApi.getNamespaces()
        
        if _cmd == 'updateApiInfo':
            return ApiApi.updateApiInfo()
        
        if _cmd == 'deleteApiInfo':
            return ApiApi.deleteApiInfo()
        
        if _cmd == 'getApiParam':
            return ApiApi.getApiParam()
        
        if _cmd == 'updateApiParam':
            return ApiApi.updateApiParam()
        
        if _cmd == 'deleteApiParam':
            return ApiApi.deleteApiParam()
        
        if _cmd == 'updateExample':
            return ApiApi.updateExample()
        
        if _cmd == 'getExample':
            return ApiApi.getExample()
        
        if _cmd == 'deleteExample':
            return ApiApi.deleteExample()
        
        if _cmd == 'updateExampleParam':
            return ApiApi.updateExampleParam()
        
        if _cmd == 'getExampleParam':
            return ApiApi.getExampleParam()
        
        if _cmd == 'testExample':
            return ApiApi.testExample()
        
        if _cmd == 'getJqCode':
            return ApiApi.getJqCode()
    pass

if __name__ == "__main__":
    pass




from IutyLib.database.mysql import MySql
from IutyLib.database.dbbase import *
from flask import session,request,send_from_directory
from flask_restful import Resource
import datetime

from IutyProxy.stock.ResistanceProxy import ResistanceProxy
from IutyApi.stock.monitor_ import Frm_Monitor_Data

dbg = False
if dbg:
    mysql = MySql('139.9.137.187','root','fastcorp','stock',8510)
else:
    mysql = MySql('localhost','root','fastcorp','stock')


class Srv_Resistance_Data(mysql.Model):
    def queryRecord(self):
        data = self.query()
        return data
        
    def addRecord(self,code,pu,pd,trend):
        self.add(value=[{"code":code,"pu":pu,"pd":pd,"trend":trend,"au":0,"ad":0}])
        pass
    
    def updateRecord(self,code,pu,pd,trend):
        self.update(value=[{"pu":pu,"pd":pd,"trend":trend}],where=r"code='{}'".format(code))
        pass
    
    def deleteRecord(self,code):
        self.delete(where=r"code = '{}'".format(code))
        pass
    
    def setMonitor(self,code,au,ad):
        self.update(value=[{"au":au,"ad":ad}],where=r"code='{}'".format(code))
    pass

    
class ResistanceApi(Resource):
    #srv_resistance_data
    def query():
        rtn = {"success":False}
        data = Srv_Resistance_Data().queryRecord()
        for d in data:
            d["pu"] = round(float(d["pu"]),2)
            d["pd"] = round(float(d["pd"]),2)
            d["trend"] = int(d["trend"])
        
        rtn["success"] = True
        rtn["data"] = data
        return rtn
    
    def inquery():
        rtn = {"success":False}
        code = request.form.get("code")
        if not code:
            rtn["error"] = "code is nesserary"
            return rtn
        
        try:
            pu,pd,trend = ResistanceProxy.getResistance(code)
            rtn["data"] = {"pu":pu,"pd":pd,"trend":trend}
            rtn["success"] = True
        except Exception as err:
            rtn["error"] = "inquery error "+str(err)
        return rtn
    
    def update():
        rtn = {"success":False}
        qr = ResistanceApi.query()
        for d in qr["data"]:
            try:
                pu,pd,trend = ResistanceProxy.getResistance(d["code"])
                Srv_Resistance_Data().updateRecord(d["code"],pu,pd,trend)
            except Exception as err:
                print(str(err))
        
        rtn["success"] = True
        return rtn
    
    def follow():
        rtn = {"success":False}
        code = request.form.get("code")
        if not code:
            rtn["error"] = "code is nesserary"
            return rtn
        
        try:
            pu,pd,trend = ResistanceProxy.getResistance(code)
            Srv_Resistance_Data().addRecord(code,pu,pd,trend)
            rtn["success"] = True
        except Exception as err:
            rtn["error"] = "inquery error " + str(err)
        
        return rtn
    
    def unfollow():
        rtn = {"success":False}
        code = request.form.get("code")
        if not code:
            rtn["error"] = "code is nesserary"
            return rtn
        
        Srv_Resistance_Data().deleteRecord(code)
        rtn["success"] = True
        return rtn
    
    #frm_resistance_monitor
    def setMonitor():
        rtn = {"success":False}
        code = request.form.get("code")
        if not code:
            rtn["error"] = "code is nesserary"
            return rtn

        au = request.form.get("au")
        if not au:
            rtn["error"] = "au is nesserary"
            return rtn

        ad = request.form.get("ad")
        if not ad:
            rtn["error"] = "status is nesserary"
            return rtn
        
        Srv_Resistance_Data().setMonitor(code,au,ad)

        rtn["success"] = True
        return rtn
    
    def updateMonitor():
        rtn = {"success":False}
        db1 = Frm_Monitor_Data()
        db1.clearRecord("a.r")
        
        db0 = Srv_Resistance_Data()
        data = db0.queryRecord()
        print(data)
        for d in data:
            if int(d["au"]) == 1:
                db1.addRecord(d["code"],d["pu"],1,"a.r")
            if int(d["ad"]) == 1:
                db1.addRecord(d["code"],d["pd"],0,"a.r")
        
        rtn["success"] = True
        return rtn
    
    def post(self):
        _cmd = request.form.get("cmd")
        if _cmd == "query":
            return ResistanceApi.query()
        
        if _cmd == "inquery":
            return ResistanceApi.inquery()
        
        if _cmd == "follow":
            return ResistanceApi.follow()
        
        if _cmd == "unfollow":
            return ResistanceApi.unfollow()
        
        if _cmd == "setMonitor":
            return ResistanceApi.setMonitor()
        
        if _cmd == "update":
            return ResistanceApi.update()
        
        if _cmd == "updateMonitor":
            return ResistanceApi.updateMonitor()
    pass
    
if __name__ == "__main__":
    db = Srv_Resistance_Data()
    db.setMonitor("600703",1,0)
    #print(db.queryRecord())

    
    pass


from IutyLib.database.mysql import MySql
from IutyLib.database.dbbase import *
from flask import session,request,send_from_directory
from flask_restful import Resource
import datetime


dbg = False
if dbg:
    mysql = MySql('139.9.137.187','root','fastcorp','stock',8510)
else:
    mysql = MySql('localhost','root','fastcorp','stock')

class Frm_Monitor_Data(mysql.Model):
    def addRecord(self,code,target,type,recordusr):
        date = datetime.date.today()
        self.add(value=[{"code":code,"target":float(target),"type":int(type),"recordusr":recordusr,"recorddate":date}])
        pass
    
    def deleteRecord(self,code,type,usr="t.yu"):
        self.delete(where=r"code='{}' and type = '{}' and recordusr = '{}'".format(code,type,usr))
        pass
    
    def replaceRecord(self,code,type,target,recordusr="t.yu"):
        date = datetime.date.today()
        self.replace(value=[{"code":code,"target":float(target),"type":int(type),"recordusr":recordusr,"recorddate":date}],where=r"code='{}' and type = '{}' and recordusr = '{}'".format(code,type,usr))
        pass
    
    def clearRecord(self,recordusr="t.yu"):
        self.delete(where=r"recordusr='{}'".format(recordusr))
        pass
    
    def queryRecord(self):
        data = self.query()
        for d in data:
            d["target"] = float(d["target"])
            d["recorddate"] = datetime.datetime.strftime(d["recorddate"],"%y-%m-%d")
        
        return data
        pass
    pass
    
class MonitorApi(Resource):
    def add():
        rtn = {"success":False}
        _code = request.form.get("code")
        _target = request.form.get("target")
        _type = request.form.get("type")
        _recordusr = request.form.get("recordusr")
        if not _code:
            rtn["error"] = "code is nesserary"
            return rtn
        if not _target:
            rtn["error"] = "target is nesserary"
            return rtn
        if not _type:
            rtn["error"] = "type is nesserary"
            return rtn
        if not _recordusr:
            rtn["error"] = "recordusr is nesserary"
            return rtn
        date = datetime.date.today()
        Frm_Monitor_Data().addRecord(_code,_target,_type,_recordusr)
        
        rtn["success"] = True
        return rtn
    
    def query():
        rtn = {"success":False}
        data = Frm_Monitor_Data().queryRecord()
        
        rtn["data"] = data
        rtn["success"] = True
        return rtn
    
    def delete():
        rtn = {"success":False}
        _code = request.form.get("code")
        if not _code:
            rtn["error"] = "code in nesserary"
            return rtn
        
        _type = request.form.get("type")
        if not _type:
            rtn["error"] = "type in nesserary"
            return rtn
        
        Frm_Monitor_Data().deleteRecord(_code,_type)
        rtn["success"] = True
        return rtn
    
    def post(self):
        _cmd = request.form.get('cmd')
        if _cmd == 'query':
            return MonitorApi.query()
        
        if _cmd == 'add':
            return MonitorApi.add()
        
        if _cmd == 'delete':
            return MonitorApi.delete()
    pass

if __name__ == "__main__":
    #Frm_Monitor_Data().addRecord("000002",5.17,"1")
    #Frm_Monitor_Data().deleteRecord("000001")
    Frm_Monitor_Data().queryRecord()

